@@ -7,7 +7,7 @@ saveDialog::saveDialog(QWidget *parent) :
 {
     ui->setupUi(this);
     ui->saveBtnBox->addButton("Save", QDialogButtonBox::YesRole);
-    ui->saveBtnBox->addButton("Close", QDialogButtonBox::NoRole);
+    ui->saveBtnBox->addButton("Cancel", QDialogButtonBox::NoRole);
 
     QRegExp nameRegExp("^[a-z0-9_-\\s]*$");
     // ^                From the beginning of the string
