@@ -1,8 +1,8 @@
 #ifndef WPMANAGER_H
 #define WPMANAGER_H
 
-#include "fourimages.h"
-#include "ui_fourimages.h"
+#include "wpnew.h"
+#include "ui_wpnew.h"
 #include "deletedialog.h"
 #include "ui_deletedialog.h"
 
@@ -25,42 +25,76 @@ public:
     ~wpManager();
 
 public slots:
-    void confirmDelSet();
+    void viewNames();
+    void viewFilenames();
+    void manPrevBtnClicked();
+    void manEditBtnClicked();
+    void manDelBtnClicked();
     void delSet();
-    void updatePrevs();
     void itemChanged();
-    void editCurrent();
     void updateListAfterEdit();
 
 private:
     Ui::wpManager *ui;
 
     /************ FUNCTIONS **************/
+    void setupWPManMenuBar();
     void updateList();
     void changeCurItem(QListWidgetItem*,QListWidgetItem*);
 
+    bool fileExistsCheck();
+    void updatePrevs();
+    void editCurrent();
+    void confirmDelSet();
+
+    void fillImageSetList();
+
     /************ VARIABLES **************/
     int i;
+    int j;
+
+    bool fileExists;
 
     QList<QLabel*> manPrev;
 
     QDir imageSetDir;
     QStringList nameFilters;
-    QStringList imageSetList;
+    QStringList imageSetPreList; // All .desktop files
+
+    QVector<QVector<QString> > imageSetList; // Filtered to all containing "Type=Background Image"
+    // [#][0] = Absolute path+filename
+    // [#][1] = X-File1
+    // [#][2] = X-File2
+    // [#][3] = X-File3
+    // [#][4] = X-File4
+    // [#][5] = Name
+    int listIndex;
+    bool addIt;
+
     QList<QListWidgetItem*> itemList;
+        QFile checkFile;
 
-    QString delFileName;
     QFile delFileWithPath;
     deleteDialog* delDialog;
     bool delDialogIsMade;
 
-    QFile imageSetPrev;
+    QFile imageSetPrevFile;
     QString lineInFile;
 
-    fourImages* editWin;
+    wpNew* editWin;
     QFile editFile;
 
     int curRowBeforeEdit;
+
+    // The view-menu
+    QMenu* wpManMenu;
+    QAction* wpManViewNames;
+    QAction* wpManViewFilenames;
+
+    enum listView {
+        names,
+        filenames
+    } fileView;
 };
 
 #endif // WPMANAGER_H
